/* 
 * 祝祭日データ（日本語、日本用） ja-JP for jquery.holiday.js
 * 
 * 機能:
 *		祝祭日ツールチップの地域と言語を設定する
 * 使用:
 *		<script src="jquery.holiday_ja-JP.js"></script>
 * 注意:
 *		このファイルはHTMLページごとの設定になります。１つのHTMLページで複数の地域・言語の設定はできません。
 * 履歴:
 *   2020-10-11 現時点の“内閣府「国民の祝日」について”に対応
 *   2021-06-27 現時点の“内閣府「国民の祝日」について”(https://www8.cao.go.jp/chosei/shukujitsu/gaiyou.html)に対応
 */
$(function(){
	$.fn.holiday('setRegionData', {
		//年間の祝祭日データ
		//	形式: { month : [{ day: 日, name: 名称 }] }
		//	日の形式: (日にち | 第何 / 曜日(1:月曜日) | 日にち > 有効開始年)
		'annual':{
			'01': [
				{'day':'01','name':'元旦'},
				{'day':'2/1','name':'成人の日'}
			],
			'02': [
				{'day':'11','name':'建国記念日'},
				{'day':'23','name':'天皇誕生日','from':'2020'}
			],
			'03': [
				{'day':'spring equinox','name':'春分の日'}
			],
			'04': [
				{'day':'29','name':'昭和の日'}
			],
			'05': [
				{'day':'03','name':'憲法記念日'},
				{'day':'04','name':'みどりの日'},
				{'day':'05','name':'こどもの日'}
			],
			'07': [
				{'day':'20', 'name':'海の日','from':'1996','to':'2002'},
				{'day':'3/1','name':'海の日','from':'2003','to':'2019'},
				{'day':'3/1','name':'海の日','from':'2022'}
			],
			'08': [
				{'day':'11','name':'山の日','from':'2016','to':'2019'},
				{'day':'11','name':'山の日','from':'2022'}
			],
			'09': [
				{'day':'3/1','name':'敬老の日'},
				{'day':'autumnal equinox','name':'秋分の日'}
			],
			'10': [
				{'day':'2/1','name':'体育の日','to':'2019'},
				{'day':'2/1','name':'スポーツの日','from':'2022'}
			],
			'11': [
				{'day':'03','name':'文化の日'},
				{'day':'23','name':'勤労感謝の日'}
			],
			'12': [
				{'day':'23','name':'天皇誕生日','to':'2018'}
			]
		},
		//個別の祝祭日データ
		//	形式: { 年月 : [ { day: 日にち, name: 名称 } ] }
		'individual':{
			'201509': [{'day':'22','name':'国民の休日'}],
			'202007': [{'day':'23','name':'海の日'},{'day':'24','name':'スポーツの日'}], //オリンピック開催2020年の特例
			'202008': [{'day':'10','name':'山の日'}], //オリンピック開催2020年の特例
			'202107': [{'day':'22','name':'海の日'},{'day':'23','name':'スポーツの日'}], //オリンピック開催2021年の特例
			'202108': [{'day':'08','name':'山の日'},{'day':'09','name':'振替休日(山の日)'}], //オリンピック開催2021年の特例
			'202609': [{'day':'22','name':'国民の休日'}], //2015年時点の推定
			'203209': [{'day':'21','name':'国民の休日'}], //2015年時点の推定
			'203709': [{'day':'22','name':'国民の休日'}] //2015年時点の推定
		},
		//言語対応
		'words': {
			'substitute': '振替休日'
		}
	});
});